from enum import Enum, auto, unique
from typing import Any, cast


class StrEnum(str, Enum):  # TODO (py3.10): Import from enum
    @staticmethod
    def _generate_next_value_(
        name: str, start: int, count: int, last_values: list[Any]  # noqa: ARG004
    ) -> str:
        return name.lower()

    def __str__(self) -> str:
        return cast(str, self.value)

    def __eq__(self, value: object) -> bool:
        if isinstance(value, str):
            return str(self.value) == value
        return NotImplemented

    def __ne__(self, value: object) -> bool:
        if isinstance(value, str):
            return not self.__eq__(value)
        return NotImplemented


@unique
class TextType(StrEnum):
    COLOR_NAME = auto()
    FILE_NAME = auto()


@unique
class UnstableTextType(StrEnum):
    ABA = auto()
    ADDRESS = auto()
    ADMINISTRATIVE_UNIT = auto()
    AM_PM = auto()
    ANDROID_PLATFORM_TOKEN = auto()
    ASCII_COMPANY_EMAIL = auto()
    ASCII_EMAIL = auto()
    ASCII_FREE_EMAIL = auto()
    ASCII_SAFE_EMAIL = auto()
    BANK_COUNTRY = auto()
    BASIC_PHONE_NUMBER = auto()
    BBAN = auto()
    BOTHIFY = auto()
    BS = auto()
    BUILDING_NUMBER = auto()
    CATCH_PHRASE = auto()
    CENTURY = auto()
    CHROME = auto()
    CITY = auto()
    CITY_PREFIX = auto()
    CITY_SUFFIX = auto()
    COLOR = auto()
    COMPANY = auto()
    COMPANY_EMAIL = auto()
    COMPANY_SUFFIX = auto()
    COUNTRY = auto()
    COUNTRY_CALLING_CODE = auto()
    COUNTRY_CODE = auto()
    CREDIT_CARD_EXPIRE = auto()
    CREDIT_CARD_FULL = auto()
    CREDIT_CARD_NUMBER = auto()
    CREDIT_CARD_PROVIDER = auto()
    CREDIT_CARD_SECURITY_CODE = auto()
    CRYPTOCURRENCY_CODE = auto()
    CRYPTOCURRENCY_NAME = auto()
    CSV = auto()
    CURRENCY_CODE = auto()
    CURRENCY_NAME = auto()
    CURRENCY_SYMBOL = auto()
    CURRENT_COUNTRY = auto()
    CURRENT_COUNTRY_CODE = auto()
    DATE = auto()
    DAY_OF_MONTH = auto()
    DAY_OF_WEEK = auto()
    DGA = auto()
    DOMAIN_NAME = auto()
    DOMAIN_WORD = auto()
    DSV = auto()
    EAN = auto()
    EAN13 = auto()
    EAN8 = auto()
    EIN = auto()
    EMAIL = auto()
    EMOJI = auto()
    FILE_EXTENSION = auto()
    FILE_PATH = auto()
    FIREFOX = auto()
    FIRST_NAME = auto()
    FIRST_NAME_FEMALE = auto()
    FIRST_NAME_MALE = auto()
    FIRST_NAME_NONBINARY = auto()
    FIXED_WIDTH = auto()
    FREE_EMAIL = auto()
    FREE_EMAIL_DOMAIN = auto()
    HEX_COLOR = auto()
    HEXIFY = auto()
    HOSTNAME = auto()
    HTTP_METHOD = auto()
    IANA_ID = auto()
    IBAN = auto()
    IMAGE_URL = auto()
    INTERNET_EXPLORER = auto()
    INVALID_SSN = auto()
    IOS_PLATFORM_TOKEN = auto()
    IPV4 = auto()
    IPV4_NETWORK_CLASS = auto()
    IPV4_PRIVATE = auto()
    IPV4_PUBLIC = auto()
    IPV6 = auto()
    ISBN10 = auto()
    ISBN13 = auto()
    ISO8601 = auto()
    ITIN = auto()
    JOB = auto()
    JSON = auto()
    LANGUAGE_CODE = auto()
    LANGUAGE_NAME = auto()
    LAST_NAME = auto()
    LAST_NAME_FEMALE = auto()
    LAST_NAME_MALE = auto()
    LAST_NAME_NONBINARY = auto()
    LEXIFY = auto()
    LICENSE_PLATE = auto()
    LINUX_PLATFORM_TOKEN = auto()
    LINUX_PROCESSOR = auto()
    LOCALE = auto()
    LOCALIZED_EAN = auto()
    LOCALIZED_EAN13 = auto()
    LOCALIZED_EAN8 = auto()
    MAC_ADDRESS = auto()
    MAC_PLATFORM_TOKEN = auto()
    MAC_PROCESSOR = auto()
    MD5 = auto()
    MILITARY_APO = auto()
    MILITARY_DPO = auto()
    MILITARY_SHIP = auto()
    MILITARY_STATE = auto()
    MIME_TYPE = auto()
    MONTH = auto()
    MONTH_NAME = auto()
    MSISDN = auto()
    NAME = auto()
    NAME_FEMALE = auto()
    NAME_MALE = auto()
    NAME_NONBINARY = auto()
    NIC_HANDLE = auto()
    NUMERIFY = auto()
    OPERA = auto()
    PARAGRAPH = auto()
    PASSPORT_FULL = auto()
    PASSPORT_GENDER = auto()
    PASSPORT_NUMBER = auto()
    PASSWORD = auto()
    PHONE_NUMBER = auto()
    POSTALCODE = auto()
    POSTALCODE_IN_STATE = auto()
    POSTALCODE_PLUS4 = auto()
    POSTCODE = auto()
    POSTCODE_IN_STATE = auto()
    PREFIX = auto()
    PREFIX_FEMALE = auto()
    PREFIX_MALE = auto()
    PREFIX_NONBINARY = auto()
    PRICETAG = auto()
    PSV = auto()
    RGB_COLOR = auto()
    RGB_CSS_COLOR = auto()
    RIPE_ID = auto()
    SAFARI = auto()
    SAFE_COLOR_NAME = auto()
    SAFE_DOMAIN_NAME = auto()
    SAFE_EMAIL = auto()
    SAFE_HEX_COLOR = auto()
    SBN9 = auto()
    SECONDARY_ADDRESS = auto()
    SENTENCE = auto()
    SHA1 = auto()
    SHA256 = auto()
    SLUG = auto()
    SSN = auto()
    STATE = auto()
    STATE_ABBR = auto()
    STREET_ADDRESS = auto()
    STREET_NAME = auto()
    STREET_SUFFIX = auto()
    SUFFIX = auto()
    SUFFIX_FEMALE = auto()
    SUFFIX_MALE = auto()
    SUFFIX_NONBINARY = auto()
    SWIFT = auto()
    SWIFT11 = auto()
    SWIFT8 = auto()
    TEXT = auto()
    TIME = auto()
    TLD = auto()
    TSV = auto()
    UNIX_DEVICE = auto()
    UNIX_PARTITION = auto()
    UPC_A = auto()
    UPC_E = auto()
    URI = auto()
    URI_EXTENSION = auto()
    URI_PAGE = auto()
    URI_PATH = auto()
    URL = auto()
    USER_AGENT = auto()
    USER_NAME = auto()
    VIN = auto()
    WINDOWS_PLATFORM_TOKEN = auto()
    WORD = auto()
    YEAR = auto()
    ZIPCODE = auto()
    ZIPCODE_IN_STATE = auto()
    ZIPCODE_PLUS4 = auto()
